<?php

namespace App\Repositories\Criteria\TCM;

use Illuminate\Http\Request;
use Prettus\Repository\Contracts\CriteriaInterface;
use Prettus\Repository\Contracts\RepositoryInterface;

/**
 * Class DrugCriteria.
 *
 * @package namespace App\Repositories\Criteria\TCM;
 */
class DrugCriteria implements CriteriaInterface
{
    /**
     * Apply criteria in query repository
     *
     * @param string $model
     * @param RepositoryInterface $repository
     *
     * @return mixed
     */
    public function __construct(Request $request = null)
    {
        if (is_null($request)) {
            $this->request = \request();
        } else {
            $this->request = $request;
        }
    }

    /**
     * Apply criteria in query repository
     *
     * @param string $model
     * @param RepositoryInterface $repository
     *
     * @return mixed
     */
    public function apply($model, RepositoryInterface $repository)
    {
        if ($name = $this->request->get('name')) {
            $model = $model->where('name', 'like', "%{$name}%");
        }

        if ($letter = $this->request->get('letter')) {
            $model = $model->where('letter', 'like', "%{$letter}%");
        }

        if ($initial = $this->request->get('initial')) {
            $model = $model->where('initial', '=', $initial);
        }

        if ($keyword = $this->request->get('keyword')) {
            $model = $model->where(function ($query) use ($keyword) {
                return $query->where('name', 'like', "%{$keyword}%")->orWhere('letter', 'like', "%{$keyword}%")->orWhere('initial', '=', $keyword);
            });
        }

        if (($status = $this->request->get('status', false)) !== false) {
            $model = $model->where('status', '=', $status);
        }

        $model = $model->orderByDesc('id');

        return $model;
    }
}
