<?php

namespace App\Repositories\Models\TCM;

use App\Repositories\Models\Model;
use Prettus\Repository\Contracts\Transformable;
use Prettus\Repository\Traits\TransformableTrait;

/**
 * Class MedicalRecord.
 *
 * @package namespace App\Repositories\Models\TCM;
 */
class MedicalRecord extends Model implements Transformable
{
    use TransformableTrait;

    protected $table = 'tcm_medical_records';


    /**
     * The attributes that are mass assignable.
     *
     * @var array
     */
    protected $guarded = [];

    protected static function booted()
    {
        self::language();
    }

    public function patient()
    {
        return $this->belongsTo(Patient::class);
    }

    public function department_category()
    {
        return $this->belongsTo(Category::class, 'department', 'id');
    }

    public function setUpTonguebaseImgAttribute($val)
    {
        $this->attributes['up_tonguebase_img'] = '-' . arr2str($val, '-') . '-';
    }

    public function getUpTonguebaseImgAttribute($val)
    {
        return str2arr(trim($val, '-'), '-');
    }

    public function setAllergiesHistoryAttribute($val)
    {
        $this->attributes['allergies_history'] = '-' . arr2str($val, '-') . '-';
    }

    public function getAllergiesHistoryAttribute($val)
    {
        return str2arr(trim($val, '-'), '-');
    }

    public function setPastHistoryAttribute($val)
    {
        if (count($val) == 0) return '';
        $this->attributes['past_history'] = '-' . arr2str($val, '-') . '-';
    }

    public function getPastHistoryAttribute($val)
    {
        return str2arr(trim($val, '-'), '-');
    }

}
