<?php

namespace App\Repositories\Transformers\TCM;

use App\Repositories\Enums\VisitEnum;
use App\Repositories\Models\Base\Resource;
use Carbon\Carbon;
use League\Fractal\TransformerAbstract;
use App\Repositories\Models\TCM\MedicalRecord;

/**
 * Class MedicalRecordTransformer.
 *
 * @package namespace App\Repositories\Transformers\TCM;
 */
class MedicalRecordTransformer extends TransformerAbstract
{
    /**
     * Transform the MedicalRecord entity.
     *
     * @param \App\Repositories\Models\TCM\MedicalRecord $model
     *
     * @return array
     */
    public function transform(MedicalRecord $model)
    {
        return [
            'id' => (int)$model->id,
            'is_once' => $model->is_once,
            'is_once_text' => VisitEnum::getDescription($model->is_once),
            'chief_complaint' => $model->chief_complaint,
            'history_of_present_illness' => $model->history_of_present_illness,
            'pulse_desc' => $model->pulse_desc,
            'tongue_desc' => $model->tongue_desc,
            'common_sign' => $model->common_sign,
            'chinese_tra_diagnosis' => $model->chinese_tra_diagnosis,
            'treatment_method' => $model->treatment_method,
            'assist_examination' => $model->assist_examination,
            'past_history' => $model->past_history,
            'allergies_history' => $model->allergies_history,
            'doctor_advice' => $model->doctor_advice,
            'temperature' => $model->temperature,
            'blood_pressure_max' => $model->blood_pressure_max,
            'blood_pressure_min' => $model->blood_pressure_min,
            'heart_rate' => $model->heart_rate,
            'breath_rate' => $model->breath_rate,
            'height' => $model->height,
            'weight' => $model->weight,
            'bmi' => $model->bmi,
            'blood_sugar' => $model->blood_sugar,
            'blood_oxygen' => $model->blood_oxygen,
            'other_physical_examination' => $model->other_physical_examination,
            'up_tonguebase_img' => $model->up_tonguebase_img,
            'up_tonguebase_img_resource' => Resource::query()->whereIn('id', $model->up_tonguebase_img)->select(['id', 'url', 'path'])->get(),
            'patient_id' => $model->patient_id,
            "patient" => $model->patient,
            'hospital' => $model->hospital,
            'department' => $model->department,
            'department_name' => $model->department_category ? $model->department_category->title : '--',
            'doctor' => $model->doctor,
            'status' => $model->status,

            'created_at' => $model->created_at->format(Carbon::DEFAULT_TO_STRING_FORMAT),
            'updated_at' => $model->updated_at->format(Carbon::DEFAULT_TO_STRING_FORMAT)
        ];
    }
}
